import webiopi
import time
GPIO = webiopi.GPIO
########################################################
#　サーボ制御
########################################################
import wiringpi
def getServoDutyForWebIOPi(val):
    val_min = 0.0
    val_max = 1.0
    servo_min = 25   # 50Hzで, 0.7ms
    servo_max = 123  # 50Hzで, 2.0ms

    duty = int((servo_max-servo_min)*(val-val_min)/(val_max-val_min) + servo_min)
    return duty

wiringpi.wiringPiSetupGpio() # GPIO名で番号指定

wiringpi.pinMode(18, wiringpi.GPIO.PWM_OUTPUT)
wiringpi.pinMode(19, wiringpi.GPIO.PWM_OUTPUT)

wiringpi.pwmSetMode(wiringpi.GPIO.PWM_MODE_MS) # 周波数固定
wiringpi.pwmSetClock(375) # 50 Hz

wiringpi.pwmWrite(18, getServoDutyForWebIOPi(0.5))
wiringpi.pwmWrite(19, getServoDutyForWebIOPi(0.5))

@webiopi.macro
def setHwPWM1(duty, commandID):
    wiringpi.pwmWrite(18, getServoDutyForWebIOPi(float(duty)))
@webiopi.macro
def setHwPWM2(duty, commandID):
    wiringpi.pwmWrite(19, getServoDutyForWebIOPi(float(duty)))
###################################################
# ＬＥＤ制御
###################################################
webiopi.setDebug()
GPIO = webiopi.GPIO

LIGHT = 23 # GPIO pin using BCM numbering
GPIO.setFunction(LIGHT, GPIO.OUT)
GPIO.digitalWrite(LIGHT, GPIO.HIGH)

@webiopi.macro
def lighton():
        GPIO.digitalWrite(LIGHT, GPIO.HIGH)

@webiopi.macro
def lightoff():
        GPIO.digitalWrite(LIGHT, GPIO.LOW)

# destroy function is called at WebIOPi shutdown
def destroy():
    GPIO.digitalWrite(LIGHT, GPIO.LOW)
##############################################################
#モータ制御
#############################################################
PIN_L1 = 27
PIN_L2 = 17
PIN_R1 = 11
PIN_R2 = 9

g_mode = 0
g_percentage = 50

GPIO.setFunction( PIN_L1, GPIO.PWM )
GPIO.setFunction( PIN_L2, GPIO.PWM )
GPIO.setFunction( PIN_R1, GPIO.PWM )
GPIO.setFunction( PIN_R2, GPIO.PWM )

def MotorDrive( iIn1Pin, iIn2Pin, percentage ):
  if 100 < percentage:
    percentage = 100
  if -100 > percentage:
    percentage = -100
  if 10 > percentage and -10 < percentage:
    GPIO.pwmWrite( iIn1Pin, 0.0 )
    GPIO.pwmWrite( iIn2Pin, 0.0 )
  elif 0 < percentage:
    GPIO.pwmWrite( iIn1Pin, percentage * 0.01 )
    GPIO.pwmWrite( iIn2Pin, 0.0 )
  else:
      GPIO.pwmWrite( iIn1Pin, 0.0 )
      GPIO.pwmWrite( iIn2Pin, -percentage * 0.01 )

@webiopi.macro
def ChangeDriveMode( mode ):
  if mode == "0":
    webiopi.debug("ChangeDriveMode : Stop")
    MotorDrive( PIN_L1, PIN_L2, 0 );
    MotorDrive( PIN_R1, PIN_R2, 0 );
  elif mode == "1":
    webiopi.debug("ChangeDriveMode : Forward")
    MotorDrive( PIN_L1, PIN_L2, g_percentage );
    MotorDrive( PIN_R1, PIN_R2, g_percentage );
  elif mode == "2":
    webiopi.debug("ChangeDriveMode : Backward")
    MotorDrive( PIN_L1, PIN_L2, -g_percentage );
    MotorDrive( PIN_R1, PIN_R2, -g_percentage );
  elif mode == "3":
    webiopi.debug("ChangeDriveMode : CW")
    MotorDrive( PIN_L1, PIN_L2, g_percentage );
    MotorDrive( PIN_R1, PIN_R2, -g_percentage );
  elif mode == "4":
    webiopi.debug("ChangeDriveMode : CCW")
    MotorDrive( PIN_L1, PIN_L2, -g_percentage );
    MotorDrive( PIN_R1, PIN_R2, g_percentage );
  global g_mode
  g_mode = mode

@webiopi.macro
def ChangeVoltageLevel( level ):
  webiopi.debug("ChangeVoltageLevel : %s" % (level))
  global g_percentage
  g_percentage = 1 * int(level)
  ChangeDriveMode( g_mode )
